
importClass(Packages.org.dspace.xmlui.aspect.administrative.entity.FlowEntityUtils);
importClass(Packages.org.dspace.utils.DSpace);



/**
 * Send the current page and wait for the flow to be continued. This method will
 * preform two usefull actions: set the flow parameter & add result information.
 *
 * The flow parameter is used by the sitemap to seperate requests comming from a
 * flow script from just normal urls.
 *
 * The result object could potentialy contain a notice message and a list of
 * errors. If either of these are present then they are added to the sitemap's
 * parameters.
 */
function sendPageAndWait(uri,bizData,result)
{
    if (bizData == null)
        bizData = {};

    if (result != null)
    {
        var outcome = result.getOutcome();
        var header = result.getHeader();
        var message = result.getMessage();
        var characters = result.getCharacters();

        if (message != null || characters != null)
        {
            bizData["notice"]     = "true";
            bizData["outcome"]    = outcome;
            bizData["header"]     = header;
            bizData["message"]    = message;
            bizData["characters"] = characters;
        }

        var errors = result.getErrorString();
        if (errors != null)
        {
            bizData["errors"] = errors;
        }
    }

    // just to remember where we came from.
    bizData["flow"] = "true";
    cocoon.sendPageAndWait(uri,bizData);
}



/*********************
 * Entry Point flows
 *********************/

function startEditEntity(){

    var entityID = cocoon.request.get("entityID");

    //TODO: check authorization
    doEditEntity(entityID);

    //If we come here go back to the enitity page
    var entity = new DSpace().getStorageService().getEntityById(entityID);
    cocoon.redirectTo(cocoon.request.getContextPath()+ "/handle/" + entity.getPath() + "/" + entity.getName(), true);
    cocoon.exit();    
}



/**************************
 * Edit Entity flows
 **************************/

/**
 * Edit a single entity.
 */
function doEditEntity(entityID){
    // Always go to the status page first
    doEditEntityStatus(entityID);

    do {
        if (cocoon.request.get("submit_return"))
        {
            // go back to where ever we came from.
            return null;
        }
        else if (cocoon.request.get("submit_status"))
        {
            doEditEntityStatus(entityID);
        }
        else if (cocoon.request.get("submit_metadata"))
        {
            doEditEntityMetadata(entityID);
        }
        else
        {
            // This case should never happen but to prevent an infinite loop
            // from occuring let's just return null.
            return null;
        }

    }while(true);

}

/**
 * Show status of an entity
 */
function doEditEntityStatus(entityID)
{
    var result;
    do {
        sendPageAndWait("admin/entity/status", {"entityID":entityID}, result);

        result = null;

        if (cocoon.request.get("submit_upload")){
            result = FlowEntityUtils.modifyPrimaryFile(entityID, cocoon.request);
        }
        else if(cocoon.request.get("submit_return") || cocoon.request.get("submit_status") || cocoon.request.get("submit_metadata"))
        {
            // go back to where ever we came from.
            return null;
        }
    }while(true);
    
}


/**
 * Allow the user to update, remove, and add new metadata to the entity.
 */
function doEditEntityMetadata(entityID)
{
    var result;
    do{
        sendPageAndWait("admin/entity/metadata",{"entityID":entityID},result);
        if(cocoon.request.get("submit_return"))
        {
            //Go back to where we came from
            return null;
        }
        else if(cocoon.request.get("submit_update"))
        {
            //Update our fields
            result = FlowEntityUtils.processUpdateEntityMetadata(entityID, cocoon.request);
        }
        else if(cocoon.request.get("submit_add"))
        {
            //Add our new metadata field
            result = FlowEntityUtils.processAddEntityMetadata(entityID, cocoon.request);
        }
        else
        {
            // This case should never happen but to prevent an infinite loop
            // from occuring let's just return null.
            return null;
        }
    }while(true);
}
